@@ -32,7 +32,7 @@
 #include <QTimer>
 #include <qplatformdefs.h>
 
-#include <KActivities/Consumer>
+#include <PlasmaActivities/Consumer>
 #include <KAuthorized>
 #include <KConfigGroup>
 #include <KDirWatch>
@@ -1207,7 +1207,7 @@ void FolderModel::drop(QQuickItem *target, QObject *dropEvent, int row, bool sho
 
     KIO::DropJobFlag flag = showMenuManually ? KIO::ShowMenuManually : KIO::DropJobDefaultFlags;
     KIO::DropJob *dropJob = KIO::drop(&ev, dropTargetUrl, flag);
-    dropJob->uiDelegate()->setAutoErrorHandlingEnabled(true);
+    dropJob->setUiDelegate(new KNotificationJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled));
 
     // No menu will be shown so skip copying QMimeData
     if (mimeData->urls().empty()) {
@@ -1289,7 +1289,7 @@ void FolderModel::dropCwd(QObject *dropEvent)
     ev.setDropAction(proposedAction);
 
     KIO::DropJob *dropJob = KIO::drop(&ev, m_dirModel->dirLister()->url().adjusted(QUrl::PreferLocalFile));
-    dropJob->uiDelegate()->setAutoErrorHandlingEnabled(true);
+    dropJob->setUiDelegate(new KNotificationJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled));
 }
 
 void FolderModel::changeSelection(const QItemSelection &selected, const QItemSelection &deselected)
@@ -1865,7 +1865,7 @@ void FolderModel::openContextMenu(QQuickItem *visualParent, Qt::KeyboardModifier
 
         // Copy To, Move To
         KSharedConfig::Ptr dolphin = KSharedConfig::openConfig(QStringLiteral("dolphinrc"));
-        if (KConfigGroup(dolphin, "General").readEntry("ShowCopyMoveMenu", false)) {
+        if (KConfigGroup(dolphin, QStringLiteral("General")).readEntry("ShowCopyMoveMenu", false)) {
             m_copyToMenu->setUrls(urls);
             m_copyToMenu->setReadOnly(!itemProperties.supportsMoving());
             m_copyToMenu->addActionsTo(menu);
@@ -2023,7 +2023,17 @@ void FolderModel::setApplet(Plasma::Applet *applet)
                 Plasma::Corona *corona = containment->corona();
 
                 if (corona) {
-                    m_screenMapper->setCorona(corona, m_currentActivity);
+                    connect(corona, &Plasma::Corona::screenRemoved, this, [this](int screenId) {
+                        if (m_screen == screenId) {
+                            m_screenMapper->removeScreen(screenId, m_currentActivity, resolvedUrl());
+                        }
+                    });
+                    connect(corona, &Plasma::Corona::screenAdded, this, [this](int screenId) {
+                        if (m_screen == screenId) {
+                            m_screenMapper->addScreen(screenId, m_currentActivity, resolvedUrl());
+                        }
+                    });
+                    m_screenMapper->setCorona(corona);
                 }
                 setScreen(containment->screen());
                 connect(containment, &Plasma::Containment::screenChanged, this, &FolderModel::setScreen);
@@ -2124,7 +2134,7 @@ void FolderModel::restoreSelectedFromTrash()
 bool FolderModel::isTrashEmpty()
 {
     KConfig trashConfig(QStringLiteral("trashrc"), KConfig::SimpleConfig);
-    return trashConfig.group("Status").readEntry("Empty", true);
+    return trashConfig.group(QStringLiteral("Status")).readEntry("Empty", true);
 }
 
 void FolderModel::undoTextChanged(const QString &text)
@@ -2142,6 +2152,6 @@ void FolderModel::createFolder()
 
 bool FolderModel::isDeleteCommandShown()
 {
-    KConfigGroup cg(KSharedConfig::openConfig(), "KDE");
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("KDE"));
     return cg.readEntry("ShowDeleteCommand", false);
 }
