@@ -20,14 +20,10 @@
 #include <QPixmap>
 #include <QVBoxLayout>
 #include <QWidget>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QX11Info>
-#else
 #include <QtGui/private/qtx11extras_p.h>
-#endif
 
-#include "workspace_options.h"
 #include "keyboardmiscsettings.h"
+#include "workspace_options.h"
 
 #include "bindings.h"
 #include "flags.h"
@@ -93,7 +89,7 @@ void KCMKeyboardWidget::handleParameters(const QVariantList &args)
     // TODO: improve parameter handling
     setCurrentIndex(TAB_HARDWARE);
     for (const auto &arg : args) {
-        if (arg.type() == QVariant::String) {
+        if (arg.typeId() == QMetaType::Type::QString) {
             const QString str = arg.toString();
             if (str == QLatin1String("--tab=layouts")) {
                 setCurrentIndex(TAB_LAYOUTS);
@@ -122,21 +118,23 @@ void KCMKeyboardWidget::defaults()
     auto *xkbOptionModel = dynamic_cast<XkbOptionsTreeModel *>(uiWidget->xkbOptionsTreeView->model());
     xkbOptionModel->setXkbOptions(keyboardConfig->defaultXkbOptionsValue());
     keyboardConfig->setDefaults();
+    if (actionCollection == nullptr) {
+        actionCollection = new KeyboardLayoutActionCollection(this, true);
+    }
+    actionCollection->setLastUsedLayoutShortcut(QKeySequence(Qt::META | Qt::ALT | Qt::Key_L));
+    updateShortcutsUI();
 }
 
 bool KCMKeyboardWidget::isSaveNeeded() const
 {
-    return keyboardModelFromUI() != keyboardConfig->keyboardModel() ||
-            switchingPolicyFromUI() != keyboardConfig->switchingPolicy() ||
-            xkbOptionsFromUI() != keyboardConfig->xkbOptions() ||
-            keyboardConfig->layoutsSaveNeeded();
+    return keyboardModelFromUI() != keyboardConfig->keyboardModel() || switchingPolicyFromUI() != keyboardConfig->switchingPolicy()
+        || xkbOptionsFromUI() != keyboardConfig->xkbOptions() || keyboardConfig->layoutsSaveNeeded();
 }
 
 bool KCMKeyboardWidget::isDefault() const
 {
-    return keyboardModelFromUI() == keyboardConfig->defaultKeyboardModelValue() &&
-            switchingPolicyFromUI() == keyboardConfig->defaultSwitchingPolicyValue() &&
-            xkbOptionsFromUI() == keyboardConfig->xkbOptions();
+    return keyboardModelFromUI() == keyboardConfig->defaultKeyboardModelValue() && switchingPolicyFromUI() == keyboardConfig->defaultSwitchingPolicyValue()
+        && xkbOptionsFromUI() == keyboardConfig->xkbOptions();
 }
 
 void KCMKeyboardWidget::setDefaultIndicator(bool visible)
@@ -205,7 +203,7 @@ void KCMKeyboardWidget::uiChanged()
 
 void KCMKeyboardWidget::initializeKeyboardModelUI()
 {
-    for (const ModelInfo *modelInfo : qAsConst(rules->modelInfos)) {
+    for (const ModelInfo *modelInfo : std::as_const(rules->modelInfos)) {
         QString vendor = modelInfo->vendor;
         if (vendor.isEmpty()) {
             vendor = i18nc("unknown keyboard model vendor", "Unknown");
@@ -219,12 +217,7 @@ void KCMKeyboardWidget::initializeKeyboardModelUI()
 
 void KCMKeyboardWidget::addLayout()
 {
-    AddLayoutDialog dialog(rules,
-                           flags,
-                           keyboardModelFromUI(),
-                           xkbOptionsFromUI(),
-                           false,
-                           this);
+    AddLayoutDialog dialog(rules, flags, keyboardModelFromUI(), xkbOptionsFromUI(), false, this);
     dialog.setModal(true);
     if (dialog.exec() == QDialog::Accepted) {
         keyboardConfig->layouts.append(dialog.getSelectedLayoutUnit());
@@ -316,14 +309,18 @@ void KCMKeyboardWidget::initializeLayoutsUI()
 
     uiWidget->kdeKeySequence->setModifierlessAllowed(false);
 
+    uiWidget->toggleLastUsedLayoutKeySequence->setModifierlessAllowed(false);
+
     uiWidget->kcfg_osdKbdLayoutChangedEnabled->setText(m_workspaceOptions.osdKbdLayoutChangedEnabledItem()->label());
     uiWidget->kcfg_osdKbdLayoutChangedEnabled->setToolTip(m_workspaceOptions.osdKbdLayoutChangedEnabledItem()->toolTip());
 
     connect(uiWidget->addLayoutBtn, &QAbstractButton::clicked, this, &KCMKeyboardWidget::addLayout);
     connect(uiWidget->removeLayoutBtn, &QAbstractButton::clicked, this, &KCMKeyboardWidget::removeLayout);
     connect(uiWidget->layoutsTableView->selectionModel(), &QItemSelectionModel::selectionChanged, this, &KCMKeyboardWidget::layoutSelectionChanged);
-    connect(uiWidget->layoutsTableView->model(), qOverload<const QModelIndex &, const QModelIndex &, const QVector<int> &>(&QAbstractItemModel::dataChanged),
-            this, &KCMKeyboardWidget::uiChanged);
+    connect(uiWidget->layoutsTableView->model(),
+            qOverload<const QModelIndex &, const QModelIndex &, const QList<int> &>(&QAbstractItemModel::dataChanged),
+            this,
+            &KCMKeyboardWidget::uiChanged);
 
     connect(uiWidget->moveUpBtn, &QAbstractButton::clicked, this, &KCMKeyboardWidget::moveUp);
     connect(uiWidget->moveDownBtn, &QAbstractButton::clicked, this, &KCMKeyboardWidget::moveDown);
@@ -333,7 +330,8 @@ void KCMKeyboardWidget::initializeLayoutsUI()
     connect(uiWidget->xkb3rdLevelClearBtn, &QAbstractButton::clicked, this, &KCMKeyboardWidget::clear3rdLevelShortcuts);
 
     connect(uiWidget->kdeKeySequence, &KKeySequenceWidget::keySequenceChanged, this, &KCMKeyboardWidget::alternativeShortcutChanged);
-    connect(uiWidget->switchingPolicyButtonGroup, SIGNAL(buttonClicked(int)), this, SLOT(uiChanged()));
+    connect(uiWidget->toggleLastUsedLayoutKeySequence, &KKeySequenceWidget::keySequenceChanged, this, &KCMKeyboardWidget::lastUsedLayoutShortcutChanged);
+    connect(uiWidget->switchingPolicyButtonGroup, &QButtonGroup::idClicked, this, &KCMKeyboardWidget::uiChanged);
     connect(uiWidget->switchingPolicyButtonGroup, &QButtonGroup::idClicked, this, &KCMKeyboardWidget::updateUiDefaultIndicator);
 
     connect(uiWidget->xkbGrpShortcutBtn, &QAbstractButton::clicked, this, &KCMKeyboardWidget::scrollToGroupShortcut);
@@ -386,6 +384,20 @@ void KCMKeyboardWidget::alternativeShortcutChanged(const QKeySequence &seq)
     actionCollection->setToggleShortcut(uiWidget->kdeKeySequence->keySequence());
 }
 
+void KCMKeyboardWidget::lastUsedLayoutShortcutChanged(const QKeySequence &seq)
+{
+    Q_UNUSED(seq)
+
+    if (rules == nullptr) {
+        return;
+    }
+
+    if (actionCollection == nullptr) {
+        actionCollection = new KeyboardLayoutActionCollection(this, true);
+    }
+    actionCollection->setLastUsedLayoutShortcut(uiWidget->toggleLastUsedLayoutKeySequence->keySequence());
+}
+
 void KCMKeyboardWidget::switchKeyboardShortcutChanged()
 {
     if (rules == nullptr) {
@@ -500,7 +512,7 @@ void KCMKeyboardWidget::moveSelectedLayouts(int shift)
         uiChanged();
 
         QItemSelection selection;
-        for (const int row : qAsConst(selectionRows)) {
+        for (const int row : std::as_const(selectionRows)) {
             QModelIndex topLeft = layoutsTableModel->index(row, 0, QModelIndex());
             QModelIndex bottomRight = layoutsTableModel->index(row, layoutsTableModel->columnCount(topLeft) - 1, QModelIndex());
             selection << QItemSelectionRange(topLeft, bottomRight);
@@ -567,7 +579,7 @@ static bool xkbOptionLessThan(const OptionInfo *o1, const OptionInfo *o2)
 void KCMKeyboardWidget::initializeXkbOptionsUI()
 {
     std::sort(rules->optionGroupInfos.begin(), rules->optionGroupInfos.end(), xkbOptionGroupLessThan);
-    for (OptionGroupInfo *optionGroupInfo : qAsConst(rules->optionGroupInfos)) {
+    for (OptionGroupInfo *optionGroupInfo : std::as_const(rules->optionGroupInfos)) {
         std::sort(optionGroupInfo->optionInfos.begin(), optionGroupInfo->optionInfos.end(), xkbOptionLessThan);
     }
 
@@ -592,7 +604,7 @@ void KCMKeyboardWidget::saveXkbOptions()
 {
     QStringList options;
 
-    if(uiWidget->kcfg_resetOldXkbOptions->isChecked()) {
+    if (uiWidget->kcfg_resetOldXkbOptions->isChecked()) {
         options = xkbOptionsFromUI();
 
         // QStringLists with a single empty string are serialized as "\\0", avoid that
@@ -674,6 +686,10 @@ void KCMKeyboardWidget::updateShortcutsUI()
     const auto shortcuts = KGlobalAccel::self()->shortcut(toggleAction);
     uiWidget->kdeKeySequence->setKeySequence(shortcuts.isEmpty() ? QKeySequence() : shortcuts.first());
 
+    QAction *lastUsedLayoutAction = actionCollection->getLastUsedLayoutAction();
+    const auto lastUsedLayoutShortcuts = KGlobalAccel::self()->shortcut(lastUsedLayoutAction);
+    uiWidget->toggleLastUsedLayoutKeySequence->setKeySequence(lastUsedLayoutShortcuts.isEmpty() ? QKeySequence() : lastUsedLayoutShortcuts.first());
+
     actionCollection->loadLayoutShortcuts(keyboardConfig->layouts, rules);
     layoutsTableModel->refresh();
 }
