@@ -9,11 +9,7 @@
 #include <QProcess>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QX11Info>
-#else
 #include <QtGui/private/qtx11extras_p.h>
-#endif
 
 #include <KAboutData>
 #include <KLocalizedString>
@@ -49,7 +45,6 @@ static QString findXkbRulesFile()
 int main(int argc, char *argv[])
 {
     setenv("QT_QPA_PLATFORM", "xcb", 1);
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     Application app(argc, argv);
     Q_ASSERT(app.platformName() == QStringLiteral("xcb"));
 
