@@ -11,11 +11,7 @@
 #include <QCoreApplication>
 #include <QDebug>
 #include <QTimer>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QX11Info>
-#else
 #include <QtGui/private/qtx11extras_p.h>
-#endif
 
 #include <X11/X.h>
 #include <X11/Xatom.h>
