@@ -12,7 +12,6 @@
 #include <KCModuleData>
 #include <KCMultiDialog>
 #include <KConfigGroup>
-#include <KLocalizedString>
 #include <KPluginFactory>
 #include <KRunner/RunnerManager>
 
@@ -28,21 +27,24 @@ public:
 
     bool isDefaults() const override
     {
-        const QVector<KPluginMetaData> runnerData = Plasma::RunnerManager::runnerMetaDataList();
+        const QList<KPluginMetaData> runnerData = KRunner::RunnerManager::runnerMetaDataList();
         KConfigGroup cfgGroup(m_krunnerConfig, "Plugins");
+        if (cfgGroup.group("Favorites").readEntry("plugins", SearchConfigModule::defaultFavoriteIds()) != SearchConfigModule::defaultFavoriteIds()) {
+            return false;
+        }
         return std::all_of(runnerData.begin(), runnerData.end(), [&cfgGroup](const KPluginMetaData &pluginData) {
             return pluginData.isEnabled(cfgGroup) != pluginData.isEnabledByDefault();
         });
     }
 
 private:
-    KSharedConfigPtr m_krunnerConfig = KSharedConfig::openConfig("krunnerrc");
+    const KSharedConfigPtr m_krunnerConfig = KSharedConfig::openConfig("krunnerrc");
 };
 
 K_PLUGIN_FACTORY_WITH_JSON(SearchConfigModuleFactory, "kcm_plasmasearch.json", registerPlugin<SearchConfigModule>(); registerPlugin<KRunnerData>();)
 
 SearchConfigModule::SearchConfigModule(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KQuickAddons::ManagedConfigModule(parent, data, args)
+    : KQuickManagedConfigModule(parent, data)
     , m_model(new KPluginModel(this))
     , m_config(KSharedConfig::openConfig("krunnerrc"))
 {
@@ -56,12 +58,10 @@ SearchConfigModule::SearchConfigModule(QObject *parent, const KPluginMetaData &d
     qDBusRegisterMetaType<QHash<QString, QByteArrayList>>();
 
     connect(m_model, &KPluginModel::defaulted, this, [this](bool isDefaults) {
-        setNeedsSave(m_model->isSaveNeeded());
+        checkNeedsSave();
         setRepresentsDefaults(isDefaults);
     });
-    connect(m_model, &KPluginModel::isSaveNeededChanged, this, [this]() {
-        setNeedsSave(m_model->isSaveNeeded());
-    });
+    connect(m_model, &KPluginModel::isSaveNeededChanged, this, &SearchConfigModule::checkNeedsSave);
 }
 
 void SearchConfigModule::load()
@@ -84,10 +84,53 @@ void SearchConfigModule::reloadPlugins()
     m_model->clear();
 
     m_model->setConfig(m_config->group("Plugins"));
-    m_model->addPlugins(Plasma::RunnerManager::runnerMetaDataList(), i18n("Available Plugins"));
+    m_initialFavs = m_config->group("Plugins").group("Favorites").readEntry("plugins", defaultFavoriteIds());
+
+    QList<KPluginMetaData> metaDataList = KRunner::RunnerManager::runnerMetaDataList();
+    auto it = std::partition(metaDataList.begin(), metaDataList.end(), [this](const KPluginMetaData &plugin) {
+        return m_initialFavs.contains(plugin.pluginId());
+    });
+
+    m_favoriteMetaDataList = QList<KPluginMetaData>(metaDataList.begin(), it);
+    std::sort(m_favoriteMetaDataList.begin(), m_favoriteMetaDataList.end(), [this](const KPluginMetaData &data1, const KPluginMetaData &data2) {
+        return m_initialFavs.indexOf(data1.pluginId()) < m_initialFavs.indexOf(data2.pluginId());
+    });
+    m_model->addUnsortablePlugins(m_favoriteMetaDataList, m_favoriteCategory);
+    m_model->addPlugins(QList<KPluginMetaData>(it, metaDataList.end()), m_normalCategory);
+    setNeedsSave(false);
+}
+void SearchConfigModule::addToFavorites(const KPluginMetaData &data)
+{
+    m_model->removePlugin(data);
+    m_favoriteMetaDataList << data;
+    m_model->addUnsortablePlugins({data}, m_favoriteCategory);
+    checkNeedsSave();
+}
+void SearchConfigModule::removeFromFavorites(const KPluginMetaData &data)
+{
+    m_model->removePlugin(data);
+    m_favoriteMetaDataList.removeOne(data);
+    m_model->addPlugins({data}, m_normalCategory);
+    checkNeedsSave();
 }
 
-void SearchConfigModule::showKCM(const KPluginMetaData &data, const QStringList args, const KPluginMetaData &krunnerPluginData) const
+void SearchConfigModule::movePlugin(const KPluginMetaData &data, int destIndex)
+{
+    m_favoriteMetaDataList.removeOne(data);
+    m_favoriteMetaDataList.insert(destIndex, data);
+    checkNeedsSave();
+
+    for (int row = 0; row < m_model->rowCount(); ++row) {
+        QModelIndex index = m_model->index(row, 0); // 0 for column as we don't have multiple columns
+        QVariant value = m_model->data(index, KPluginModel::IdRole);
+        if (value == data.pluginId()) {
+            m_model->moveRow(QModelIndex(), index.row(), QModelIndex(), destIndex);
+            return;
+        }
+    }
+}
+
+void SearchConfigModule::showKCM(const KPluginMetaData &data, const QVariantList args, const KPluginMetaData &krunnerPluginData) const
 {
     auto dlg = new KCMultiDialog();
     dlg->addModule(data, args);
@@ -95,29 +138,30 @@ void SearchConfigModule::showKCM(const KPluginMetaData &data, const QStringList
     connect(dlg, qOverload<>(&KCMultiDialog::configCommitted), dlg, [krunnerPluginData]() {
         QDBusMessage message =
             QDBusMessage::createSignal(QStringLiteral("/krunnerrc"), QStringLiteral("org.kde.kconfig.notify"), QStringLiteral("ConfigChanged"));
-        const QHash<QString, QByteArrayList> changes = {
+        QHash<QString, QByteArrayList> changes = {
             {QStringLiteral("Runners"), {krunnerPluginData.pluginId().toLocal8Bit()}},
         };
-        message.setArguments({QVariant::fromValue(changes)});
+        message.setArguments({QVariant::fromValue(std::move(changes))});
         QDBusConnection::sessionBus().send(message);
     });
 }
 
 void SearchConfigModule::save()
 {
-    KQuickAddons::ManagedConfigModule::save();
-
+    KQuickManagedConfigModule::save();
+    KConfigGroup grp = m_config->group("Plugins").group("Favorites");
+    grp.writeEntry("plugins", getFavPluginIds(), KConfigGroup::Notify);
     m_model->save();
 
     QDBusMessage message = QDBusMessage::createSignal(QStringLiteral("/krunnerrc"), QStringLiteral("org.kde.kconfig.notify"), QStringLiteral("ConfigChanged"));
-    const QHash<QString, QByteArrayList> changes = {{QStringLiteral("Plugins"), {}}};
-    message.setArguments({QVariant::fromValue(changes)});
+    QHash<QString, QByteArrayList> changes{{QStringLiteral("Plugins"), {}}};
+    message.setArguments({QVariant::fromValue(std::move(changes))});
     QDBusConnection::sessionBus().send(message);
 }
 
 void SearchConfigModule::defaults()
 {
-    KQuickAddons::ManagedConfigModule::defaults();
+    KQuickManagedConfigModule::defaults();
 
     m_model->defaults();
 }
