@@ -6,7 +6,7 @@
 
 #pragma once
 
-#include <KQuickAddons/ManagedConfigModule>
+#include <KQuickManagedConfigModule>
 
 #include <KSharedConfig>
 #include <QKeySequence>
@@ -16,14 +16,14 @@
 class TabletSettings;
 class TabletData;
 
-class Tablet : public KQuickAddons::ManagedConfigModule
+class Tablet : public KQuickManagedConfigModule
 {
     Q_OBJECT
     Q_PROPERTY(DevicesModel *toolsModel READ toolsModel CONSTANT)
     Q_PROPERTY(DevicesModel *padsModel READ padsModel CONSTANT)
 
 public:
-    explicit Tablet(QObject *parent, const KPluginMetaData &metaData, const QVariantList &list);
+    explicit Tablet(QObject *parent, const KPluginMetaData &metaData);
     ~Tablet() override;
 
     void load() override;
