@@ -6,13 +6,9 @@
 
 #pragma once
 
+#include <QList>
 #include <QSocketNotifier>
-#include <QVector>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QX11Info>
-#else
 #include <QtGui/private/qtx11extras_p.h>
-#endif
 
 #include <xcb/record.h>
 #include <xcb/xcb.h>
@@ -44,6 +40,6 @@ private:
     xcb_record_context_t m_context;
     xcb_record_enable_context_cookie_t m_cookie;
 
-    QVector<bool> m_modifier, m_ignore, m_pressed;
+    QList<bool> m_modifier, m_ignore, m_pressed;
     int m_modifiersPressed, m_keysPressed;
 };
